=== modified file 'NEWS'
--- NEWS	2006-12-28 18:51:06 +0000
+++ NEWS	2007-01-04 15:37:11 +0000
@@ -1,3 +1,8 @@
+Jan 4 2007
+* 'cbranch' now supports multilevel paths.  So your repo hierarchy can match
+  your working directory hierarchy exactly.  New config option must be
+  used: "cbranch_target".  Appendpath policy should be used for this.
+
 Dec 28
 * 'import' command now honours execute bit in tarfiles
 

=== modified file '__init__.py'
--- __init__.py	2007-01-02 16:56:55 +0000
+++ __init__.py	2007-01-04 15:37:11 +0000
@@ -434,20 +434,20 @@
     """
     Create a new checkout, associated with a new repository branch.
     
-    When you cbranch, bzr looks up the repository associated with your current
-    directory in locations.conf.  It creates a new branch in that repository
-    with the same name and relative path as the checkout you request.
-
-    The locations.conf parameter is "cbranch_root".  So if you want 
-    cbranch operations in /home/jrandom/bigproject to produce branches in 
-    /home/jrandom/bigproject/repository, you'd add this:
-
-    [/home/jrandom/bigproject]
-    cbranch_root = /home/jrandom/bigproject/repository
-
-    Note that if "/home/jrandom/bigproject/repository" isn't a repository,
-    standalone branches will be produced.  Standalone branches will also
-    be produced if the source branch is in 0.7 format (or earlier).
+    When you cbranch, bzr looks up a target location in locations.conf, and
+    creates the branch there.
+
+    In your locations.conf, add the following lines:
+    [/working_directory_root]
+    cbranch_target = /branch_root
+    cbranch_target:policy = appendpath
+
+    This will mean that if you run "bzr cbranch foo/bar foo/baz" in the
+    working directory root, the branch will be created in 
+    "/branch_root/foo/baz"
+
+    NOTE: cbranch also supports "cbranch_root", but that behaviour is
+    deprecated.
     """
     takes_options = [Option("lightweight", 
                             help="Create a lightweight checkout"), 'revision']

=== modified file 'cbranch.py'
--- cbranch.py	2006-10-24 14:39:46 +0000
+++ cbranch.py	2007-01-04 15:37:11 +0000
@@ -22,15 +22,19 @@
 from bzrlib.osutils import pathjoin, basename, abspath, getcwd
 from bzrlib.urlutils import local_path_to_url
 
-def cbranch(from_location, to_location=None, revision=None, lightweight=False):
+def cbranch(from_location, to_location=None, revision=None,
+            lightweight=False):
     from_location = from_location.rstrip('/')
     if to_location is None:
         to_location = pathjoin(getcwd(), basename(from_location))
     config = LocationConfig(abspath(to_location))
-    b_root = config.get_user_option("cbranch_root")
-    if b_root is None:
-        raise BzrCommandError("Can't find cbranch_root in branches.conf")
-    b_loc = pathjoin(b_root, basename(to_location))
+    b_loc = config.get_user_option("cbranch_target")
+    if b_loc is None:
+        b_root = config.get_user_option("cbranch_root")
+        if b_root is None:
+            raise BzrCommandError("Can't find cbranch_target in"
+                                  " locations.conf")
+        b_loc = pathjoin(b_root, basename(to_location))
     cmd_branch().run(from_location, b_loc, revision=revision)
     cmd_checkout().run(b_loc, to_location, lightweight=lightweight)
     b = Branch.open(to_location)

